@@ -20,12 +20,13 @@
 #ifndef __CHEESE_FILE_UTIL_H__
 #define __CHEESE_FILE_UTIL_H__
 
-void cheese_fileutil_init();
-void cheese_fileutil_finalize();
-gchar *cheese_fileutil_get_photo_path(void);
-gchar *cheese_fileutil_get_photo_filename(int);
-gchar *cheese_fileutil_get_video_path(void);
-gchar *cheese_fileutil_get_video_filename(void);
-void cheese_fileutil_monitor_cb(GnomeVFSMonitorHandle *, const gchar *, const gchar *, GnomeVFSMonitorEventType);
+void cheese_fileutil_init ();
+void cheese_fileutil_finalize ();
+gchar *cheese_fileutil_get_photo_filename (int);
+gchar *cheese_fileutil_get_photo_path (void);
+gchar *cheese_fileutil_get_video_filename (void);
+gchar *cheese_fileutil_get_video_path (void);
+void cheese_fileutil_monitor_cb (GnomeVFSMonitorHandle *, const gchar *,
+                                 const gchar *, GnomeVFSMonitorEventType);
 
 #endif /* __CHEESE_FILE_UTIL_H__ */
